.. image:: https://img.shields.io/pypi/status/statusinfo.svg
   :target: https://pypi.org/project/statusinfo/

.. image:: https://img.shields.io/pypi/l/statusinfo.svg
   :target: https://pypi.org/project/statusinfo/

.. image:: https://img.shields.io/pypi/pyversions/statusinfo.svg
   :target: https://pypi.org/project/statusinfo/

.. image:: https://img.shields.io/pypi/v/statusinfo.svg
   :target: https://pypi.org/project/statusinfo/

.. image:: https://img.shields.io/pypi/dm/statusinfo.svg
   :target: https://pypi.org/project/statusinfo/

Usage
=====

A tool for gathering status information.

Installation
============

From PyPI
---------
::

   pip install statusinfo

From Source
-----------
::

   ./setup.py install

Development
===========

The source code is located on `GitLab <https://gitlab.com/eikendev/statusinfo>`_.
To check out the repository, the following command can be used.
::

   git clone https://gitlab.com/eikendev/statusinfo.git
